#!/usr/local/bin/python

from nikos_welt import *

class Roboter_Modell_C(Roboter):
   def __init__(self,welt):
      Roboter.__init__(self,welt,0.1)

   def kehrt(self):
      self.links()
      self.links()

   def rechts(self):
      for i in range (0,3):
         self.links()

   def links_frei(self):
      self.links()
      Zustand=self.vorne_frei()
      self.rechts()
      return Zustand

   def rechts_frei(self):
      self.rechts()
      Zustand=self.vorne_frei()
      self.links()
      return Zustand

   def Linkskurve(self):
      self.links()
      self.vor()
      self.links()

   def Rechtskurve(self):
      self.rechts()
      self.vor()
      self.rechts()

   def vor_bis_Hindernis(self):
      while self.vorne_frei():
          self.vor()

   def Feld_leeren(self):
      while not self.Feld_leer():
         self.nimm()

   def leere_bis_Hindernis(self):
      while self.vorne_frei():
         self.Feld_leeren()
         self.vor()
      self.Feld_leeren()
 


